@@ -1,5 +1,5 @@
 // ========================================================================
-// $Id: HttpFields.java,v 1.67 2004/07/19 13:12:58 hlavac Exp $
+// $Id: HttpFields.java,v 1.77 2006/11/22 20:02:15 gregwilkins Exp $
 // Copyright 199-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -38,7 +38,7 @@ import java.util.TimeZone;
 import javax.servlet.http.Cookie;
 
 import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.mortbay.log.LogFactory;
 import org.mortbay.util.DateCache;
 import org.mortbay.util.LazyList;
 import org.mortbay.util.LineInput;
@@ -57,7 +57,7 @@ import org.mortbay.util.URI;
  * This class is not synchronized as it is expected that modifications
  * will only be performed by a single thread.
  *
- * @version $Id: HttpFields.java,v 1.67 2004/07/19 13:12:58 hlavac Exp $
+ * @version $Id: HttpFields.java,v 1.77 2006/11/22 20:02:15 gregwilkins Exp $
  * @author Greg Wilkins (gregw)
  */
 public class HttpFields
@@ -169,11 +169,18 @@ public class HttpFields
                 _inlineValues=inline;
                 
                 _hashCode=__hashCode++;
-                if (__hashCode<__maxCacheSize && !__info.containsKey(name))
+                
+                if (__hashCode < __maxCacheSize)
                 {
-                    __info.put(name,this);
-                    if (!name.equals(_lname))
-                        __info.put(_lname,this);
+                    FieldInfo oldInfo = (FieldInfo)__info.get(name);
+                    if (oldInfo == null)
+                    {
+                        __info.put(name, this);
+                        if (!name.equals(_lname))
+                            __info.put(_lname, this);
+                    }
+                    else
+                        _hashCode = oldInfo._hashCode;
                 }
             }
         }
@@ -426,30 +433,15 @@ public class HttpFields
     private final static String __dateReceiveFmt[] =
     {
         "EEE, dd MMM yyyy HH:mm:ss zzz",
-        "EEE, dd MMM yyyy HH:mm:ss",
-        "EEE dd MMM yyyy HH:mm:ss zzz",
-        "EEE dd MMM yyyy HH:mm:ss",
-        "EEE MMM dd yyyy HH:mm:ss zzz",
-        "EEE MMM dd yyyy HH:mm:ss",
-        "EEE MMM-dd-yyyy HH:mm:ss zzz",
-        "EEE MMM-dd-yyyy HH:mm:ss",
-        "dd MMM yyyy HH:mm:ss zzz",
-        "dd MMM yyyy HH:mm:ss",
-        "dd-MMM-yy HH:mm:ss zzz",
-        "dd-MMM-yy HH:mm:ss",
-        "MMM dd HH:mm:ss yyyy zzz",
-        "MMM dd HH:mm:ss yyyy",
-        "EEE MMM dd HH:mm:ss yyyy zzz",
-        "EEE MMM dd HH:mm:ss yyyy",
-        "EEE, MMM dd HH:mm:ss yyyy zzz",
-        "EEE, MMM dd HH:mm:ss yyyy",
         "EEE, dd-MMM-yy HH:mm:ss zzz",
-        "EEE, dd-MMM-yy HH:mm:ss",
-        "EEE dd-MMM-yy HH:mm:ss zzz",
-        "EEE dd-MMM-yy HH:mm:ss",
+        "EEE MMM dd HH:mm:ss yyyy",
+        "EEE, dd MMM yyyy HH:mm:ss zzz",
+        "EEE, dd-MMM-yy HH:mm:ss zzz",
+        "dd MMM yyyy HH:mm:ss",
+        "dd-MMM-yy HH:mm:ss",
     };
     public static SimpleDateFormat __dateReceiveSource[];
-    public static ThreadLocal __dateReceiveCache=new ThreadLocal();
+    public static final ThreadLocal __dateReceiveCache=new ThreadLocal();
     static
     {
         __GMT.setID("GMT");
@@ -512,6 +504,12 @@ public class HttpFields
                 _version==((Field)o)._version;
         }
 
+        /* ------------------------------------------------------------ */
+        public int hashCode()
+        {
+            return _info.hashCode()*_version;
+        }
+        
         /* ------------------------------------------------------------ */
         void clear()
         {
@@ -1042,7 +1040,7 @@ public class HttpFields
             }
         }
 
-	return -1;
+        throw new IllegalArgumentException(val);
     }
     
     /* -------------------------------------------------------------- */
@@ -1362,7 +1360,7 @@ public class HttpFields
         if (qe++<0 || qe==value.length())
             return __one;
         
-        if (value.charAt(qe++)=='q');
+        if (value.charAt(qe++)=='q')
         {
             qe++;
             Map.Entry entry=__qualities.getEntry(value,qe,value.length()-qe);
@@ -1441,9 +1439,8 @@ public class HttpFields
     /* ------------------------------------------------------------ */
     /** Format a set cookie value
      * @param cookie The cookie.
-     * @param cookie2 If true, use the alternate cookie 2 header
      */
-    public void addSetCookie(Cookie cookie, boolean cookie2)
+    public void addSetCookie(Cookie cookie)
     {
         String name=cookie.getName();
         String value=cookie.getValue();
@@ -1463,32 +1460,32 @@ public class HttpFields
             if (value!=null && value.length()>0)
             {
                 if (version==0)
-                    URI.encodeString(buf,value,"\"; ");
+                    URI.encodeString(buf,value,"\";, '");
                 else
-                    QuotedStringTokenizer.quote(buf,value);
+                    buf.append(QuotedStringTokenizer.quote(value,"\";, '"));
             }
 
             if (version>0)
             {
-                buf.append(";version=");
+                buf.append(";Version=");
                 buf.append(version);
                 String comment=cookie.getComment();
                 if (comment!=null && comment.length()>0)
                 {
-                    buf.append(";comment=");
+                    buf.append(";Comment=");
                     QuotedStringTokenizer.quote(buf,comment);
                 }
             }
             String path=cookie.getPath();
             if (path!=null && path.length()>0)
             {
-                buf.append(";path=");
+                buf.append(";Path=");
                 buf.append(path);
             }
             String domain=cookie.getDomain();
             if (domain!=null && domain.length()>0)
             {
-                buf.append(";domain=");
+                buf.append(";Domain=");
                 buf.append(domain.toLowerCase());// lowercase for IE
             }
             long maxAge = cookie.getMaxAge();
@@ -1496,7 +1493,7 @@ public class HttpFields
             {
                 if (version==0)
                 {
-                    buf.append(";expires=");
+                    buf.append(";Expires=");
                     if (maxAge==0)
                         buf.append(__01Jan1970);
                     else
@@ -1504,24 +1501,25 @@ public class HttpFields
                 }
                 else
                 {
-                    buf.append (";max-age=");
+                    buf.append (";Max-Age=");
                     buf.append (cookie.getMaxAge());
                 }
             }
             else if (version>0)
             {
-                buf.append (";discard");
+                buf.append (";Discard");
             }
             if (cookie.getSecure())
             {
-                buf.append(";secure");
+                buf.append(";Secure");
             }
+            if (cookie instanceof HttpOnlyCookie)
+                buf.append(";HttpOnly");
+            
             name_value_params = buf.toString();
         }
         put(__Expires,__01Jan1970);
-        add(cookie2
-            ?HttpFields.__SetCookie2:HttpFields.__SetCookie,
-            name_value_params); 
+        add(__SetCookie,name_value_params);
     }
 
     /* ------------------------------------------------------------ */
@@ -1569,7 +1567,7 @@ public class HttpFields
     {
         protected int _i=0;
         public boolean hasNext() {return (_i<_fields.size());}
-        public Object next() {return new Entry(_i++);}
+        public Object next() throws NoSuchElementException {return new Entry(_i++);}
         public void remove() { throw new UnsupportedOperationException();}
     }
 
