@@ -1,5 +1,5 @@
 // ========================================================================
-// $Id: SocketListener.java,v 1.38 2005/08/13 00:01:24 gregwilkins Exp $
+// $Id: SocketListener.java,v 1.39 2006/02/27 13:03:50 gregwilkins Exp $
 // Copyright 199-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,6 +16,7 @@
 package org.mortbay.http;
 import java.io.IOException;
 import java.net.Socket;
+import java.net.SocketException;
 
 import org.apache.commons.logging.Log;
 import org.mortbay.log.LogFactory;
@@ -35,7 +36,7 @@ import org.mortbay.util.ThreadedServer;
  * LowResourcePersistTimeMs - time in ms that connections will persist if listener is
  *                            low on resources. 
  * </PRE>
- * @version $Id: SocketListener.java,v 1.38 2005/08/13 00:01:24 gregwilkins Exp $
+ * @version $Id: SocketListener.java,v 1.39 2006/02/27 13:03:50 gregwilkins Exp $
  * @author Greg Wilkins (gregw)
  */
 public class SocketListener
@@ -252,11 +253,12 @@ public class SocketListener
     protected HttpConnection createConnection(Socket socket)
         throws IOException
     {
-        return new HttpConnection(this,
+        HttpConnection c = new HttpConnection(this,
                                   socket.getInetAddress(),
                                   socket.getInputStream(),
                                   socket.getOutputStream(),
                                   socket);
+        return c;
     }
 
     /* ------------------------------------------------------------ */
