@@ -1,5 +1,5 @@
 // ========================================================================
-// $Id: UserRealm.java,v 1.13 2004/05/09 20:31:41 gregwilkins Exp $
+// $Id: UserRealm.java,v 1.16 2006/02/28 12:45:01 gregwilkins Exp $
 // Copyright 1996-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,7 +25,7 @@ import java.security.Principal;
  * For SSO implementation sof UserRealm should also implement SSORealm.
  *
  * @see SSORealm
- * @version $Id: UserRealm.java,v 1.13 2004/05/09 20:31:41 gregwilkins Exp $
+ * @version $Id: UserRealm.java,v 1.16 2006/02/28 12:45:01 gregwilkins Exp $
  * @author Greg Wilkins (gregw)
  */
 public interface UserRealm
@@ -54,9 +54,7 @@ public interface UserRealm
      * FORM authentication).
      * @return The authenticated UserPrincipal.
      */
-    public Principal authenticate(String username,
-                                            Object credentials,
-                                            HttpRequest request);
+    public Principal authenticate(String username,Object credentials,HttpRequest request);
 
     /* ------------------------------------------------------------ */
     /** Re Authenticate a Principal.
