@@ -1,5 +1,5 @@
 // ========================================================================
-// $Id: ServletHttpRequest.java,v 1.54 2004/07/19 13:12:59 hlavac Exp $
+// $Id: ServletHttpRequest.java,v 1.65 2005/08/13 00:01:27 gregwilkins Exp $
 // Copyright 200-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -37,7 +37,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;
 
 import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.mortbay.log.LogFactory;
 import org.mortbay.http.HttpConnection;
 import org.mortbay.http.HttpFields;
 import org.mortbay.http.HttpInputStream;
@@ -59,7 +59,7 @@ import org.mortbay.util.URI;
  * be operated on by multiple threads, then higher level
  * synchronizations may be required.
  * 
- * @version $Id: ServletHttpRequest.java,v 1.54 2004/07/19 13:12:59 hlavac Exp $
+ * @version $Id: ServletHttpRequest.java,v 1.65 2005/08/13 00:01:27 gregwilkins Exp $
  * @author Greg Wilkins (gregw)
  */
 public class ServletHttpRequest
@@ -88,7 +88,7 @@ public class ServletHttpRequest
     private String _pathInfo=null;
     private String _query=null;
     private String _pathTranslated=null;
-    private String _sessionId=null;
+    private String _requestedSessionId=null;
     private HttpSession _session=null;
     private String _sessionIdState=__SESSIONID_NOT_CHECKED;
     private ServletIn _in =null;
@@ -100,7 +100,7 @@ public class ServletHttpRequest
     /* ------------------------------------------------------------ */
     /** Constructor. 
      */
-    ServletHttpRequest(ServletHandler servletHandler,
+    public ServletHttpRequest(ServletHandler servletHandler,
                        String pathInContext,
                        HttpRequest request)
     {
@@ -122,7 +122,7 @@ public class ServletHttpRequest
         _pathInfo=null;
         _query=null;
         _pathTranslated=null;
-        _sessionId=null;
+        _requestedSessionId=null;
         _session=null;
         _sessionIdState=__SESSIONID_NOT_CHECKED;
         _in=null;
@@ -308,7 +308,7 @@ public class ServletHttpRequest
     /* ------------------------------------------------------------ */
     public Enumeration getHeaders(String s)
     {
-        Enumeration enm=_httpRequest.getFieldValues(s,",");
+        Enumeration enm=_httpRequest.getFieldValues(s);
         if (enm==null)
             return __emptyEnum;
         return enm;
@@ -417,9 +417,9 @@ public class ServletHttpRequest
     }
     
     /* ------------------------------------------------------------ */
-    void setSessionId(String pathParams)
+    void setRequestedSessionId(String pathParams)
     {
-        _sessionId=null;
+        _requestedSessionId=null;
         
         // try cookies first
         if (_servletHandler.isUsingCookies())
@@ -431,20 +431,20 @@ public class ServletHttpRequest
                 {
                     if (SessionManager.__SessionCookie.equalsIgnoreCase(cookies[i].getName()))
                     {
-                        if (_sessionId!=null)
+                        if (_requestedSessionId!=null)
                         {
                             // Multiple jsessionid cookies. Probably due to
                             // multiple paths and/or domains. Pick the first
                             // known session or the last defined cookie.
                             SessionManager manager = _servletHandler.getSessionManager();
-                            if (manager!=null && manager.getHttpSession(_sessionId)!=null)
+                            if (manager!=null && manager.getHttpSession(_requestedSessionId)!=null)
                                 break;
                             log.debug("multiple session cookies");
                         }
                         
-                        _sessionId=cookies[i].getValue();
+                        _requestedSessionId=cookies[i].getValue();
                         _sessionIdState = __SESSIONID_COOKIE;
-                        if(log.isDebugEnabled())log.debug("Got Session "+_sessionId+" from cookie");
+                        if(log.isDebugEnabled())log.debug("Got Session "+_requestedSessionId+" from cookie");
                     }
                 }
             }
@@ -457,23 +457,23 @@ public class ServletHttpRequest
                 pathParams.substring(SessionManager.__SessionURL.length()+1);
             if(log.isDebugEnabled())log.debug("Got Session "+id+" from URL");
             
-            if (_sessionId==null)
+            if (_requestedSessionId==null)
             {
-                _sessionId=id;
+                _requestedSessionId=id;
                 _sessionIdState = __SESSIONID_URL;
             }
-            else if (!id.equals(_sessionId))
+            else if (!id.equals(_requestedSessionId))
                 log.debug("Mismatched session IDs");
         }
         
-        if (_sessionId == null)
+        if (_requestedSessionId == null)
             _sessionIdState = __SESSIONID_NONE;        
     }
     
     /* ------------------------------------------------------------ */
     public String getRequestedSessionId()
     {
-        return _sessionId;
+        return _requestedSessionId;
     }
     
     /* ------------------------------------------------------------ */
@@ -504,8 +504,8 @@ public class ServletHttpRequest
         if (_session != null && ((SessionManager.Session)_session).isValid())
             return _session;
         
-	_session=null;
-
+        _session=null;
+        
         String id = getRequestedSessionId();
         
         if (id != null)
@@ -514,12 +514,12 @@ public class ServletHttpRequest
             if (_session == null && !create)
                 return null;
         }
-
+        
         if (_session == null && create)
         {
             _session=newSession();
         }
-
+        
         return _session;
     }
 
@@ -530,37 +530,9 @@ public class ServletHttpRequest
     HttpSession newSession()
     {
         HttpSession session=_servletHandler.newHttpSession(this);
-
-        if (_servletHandler.isUsingCookies())
-        {
-            Cookie cookie =
-                new Cookie(SessionManager.__SessionCookie,session.getId());
-            String path=
-                _servletHandler.getServletContext()
-                .getInitParameter(SessionManager.__SessionPath);
-            if (path==null)
-                path=getContextPath();
-            if (path==null || path.length()==0)
-                path="/";
-            
-            String domain=
-                _servletHandler.getServletContext()
-                .getInitParameter(SessionManager.__SessionDomain);
-            if (domain!=null)
-                cookie.setDomain(domain);
-            
-            String maxAge=
-                _servletHandler.getServletContext()
-                .getInitParameter(SessionManager.__MaxAge);
-            if (maxAge!=null)
-                cookie.setMaxAge(Integer.parseInt(maxAge));
-            else
-                cookie.setMaxAge(-1);
-            
-            cookie.setPath(path);
-            _servletHttpResponse.getHttpResponse().addSetCookie(cookie,false);
-        }
-
+        Cookie cookie=_servletHandler.getSessionManager().getSessionCookie(session,isSecure());
+        if (cookie!=null)
+            _servletHttpResponse.getHttpResponse().addSetCookie(cookie);
         return session;
     }
     
@@ -574,7 +546,7 @@ public class ServletHttpRequest
     /* ------------------------------------------------------------ */
     public boolean isRequestedSessionIdValid()
     {
-        return _sessionId != null && getSession(false) != null;
+        return _requestedSessionId != null && getSession(false) != null;
     }
     
     /* -------------------------------------------------------------- */
@@ -763,23 +735,17 @@ public class ServletHttpRequest
     
     /* -------------------------------------------------------------- */
     public BufferedReader getReader()
+    	throws UnsupportedEncodingException
     {
         if (_inputState!=0 && _inputState!=2)
             throw new IllegalStateException();
         if (_reader==null)
         {
-            try
-            {
-                String encoding=getCharacterEncoding();
-                if (encoding==null)
-                    encoding=StringUtil.__ISO_8859_1;
-                _reader=new BufferedReader(new InputStreamReader(getInputStream(),encoding));
-            }
-            catch(UnsupportedEncodingException e)
-            {
-                log.warn(LogSupport.EXCEPTION,e);
-                _reader=new BufferedReader(new InputStreamReader(getInputStream()));
-            }
+            String encoding=getCharacterEncoding();
+            if (encoding==null)
+                encoding=StringUtil.__ISO_8859_1;
+            _reader=new BufferedReader(new InputStreamReader(getInputStream(),encoding));
+            
         }
         _inputState=2;
         return _reader;
