@@ -1,5 +1,5 @@
 // ========================================================================
-// $Id: ServletSSL.java,v 1.4 2004/12/21 06:31:34 janb Exp $
+// $Id: ServletSSL.java,v 1.5 2006/11/22 20:02:16 gregwilkins Exp $
 // Copyright 2001-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -22,7 +22,7 @@ package org.mortbay.jetty.servlet;
  *
  * <p> Used by the SSL listener classes.
  *
- * @version $Id: ServletSSL.java,v 1.4 2004/12/21 06:31:34 janb Exp $
+ * @version $Id: ServletSSL.java,v 1.5 2006/11/22 20:02:16 gregwilkins Exp $
  * @author Brett Sealey
  */
 public class ServletSSL
@@ -59,6 +59,8 @@ public class ServletSSL
 	// Roughly ordered from most common to least common.
 	if (cipherSuite == null)
 	    return 0;
+	else if (cipherSuite.indexOf("WITH_AES_256_CBC_SHA") >= 0)
+	    return 256;
 	else if (cipherSuite.indexOf("WITH_RC4_128_") >= 0)
 	    return 128;
 	else if (cipherSuite.indexOf("WITH_AES_128_") >= 0)
