@@ -1,9 +1,18 @@
-/*
- * Created on Jun 4, 2004
- *
- * To change the template for this generated file go to
- * Window - Preferences - Java - Code Generation - Code and Comments
- */
+//========================================================================
+//$Id: Factory.java,v 1.4 2005/12/05 12:51:01 gregwilkins Exp $
+//Copyright 2004 Mort Bay Consulting Pty. Ltd.
+//------------------------------------------------------------------------
+//Licensed under the Apache License, Version 2.0 (the "License");
+//you may not use this file except in compliance with the License.
+//You may obtain a copy of the License at 
+//http://www.apache.org/licenses/LICENSE-2.0
+//Unless required by applicable law or agreed to in writing, software
+//distributed under the License is distributed on an "AS IS" BASIS,
+//WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+//See the License for the specific language governing permissions and
+//limitations under the License.
+//========================================================================
+
 package org.mortbay.log;
 
 import java.util.ArrayList;
@@ -11,7 +20,6 @@ import java.util.HashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogConfigurationException;
-import org.apache.commons.logging.LogFactory;
 
 
 /**
@@ -26,7 +34,7 @@ import org.apache.commons.logging.LogFactory;
  *   -Dorg.apache.commons.logging.LogFactory=org.mortbay.log.Factory
  * 
  */
-public class Factory extends LogFactory
+public class Factory extends org.apache.commons.logging.LogFactory
 {
      static LogImpl log = new LogImpl();
      static HashMap attributes = new HashMap();
@@ -99,7 +107,6 @@ public class Factory extends LogFactory
      */
     public void release()
     {
-        log.reset();
     }
 
     /* (non-Javadoc)
@@ -122,4 +129,4 @@ public class Factory extends LogFactory
             prefixes.add(n.substring(0,n.length()-2));
     }
 
-}
+}
\ No newline at end of file
