@@ -1,5 +1,5 @@
 // ========================================================================
-// $Id: TempByteHolder.java,v 1.7 2004/05/09 20:33:04 gregwilkins Exp $
+// $Id: TempByteHolder.java,v 1.8 2004/10/23 09:03:22 gregwilkins Exp $
 // Copyright 2002-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -114,7 +114,7 @@ public class TempByteHolder {
         _window_high = _window_size-offset;
     }
     
-    public void finalize() {
+    protected void finalize() {
         try {
             close();
         } catch (IOException e) {
