@@ -1,5 +1,5 @@
 // ========================================================================
-// $Id: TypeUtil.java,v 1.12 2004/05/09 20:33:04 gregwilkins Exp $
+// $Id: TypeUtil.java,v 1.14 2005/12/06 00:51:40 gregwilkins Exp $
 // Copyright 2002-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,7 +21,7 @@ import java.lang.reflect.Method;
 import java.util.HashMap;
 
 import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.mortbay.log.LogFactory;
 
 /* ------------------------------------------------------------ */
 /** TYPE Utilities.
@@ -29,7 +29,7 @@ import org.apache.commons.logging.LogFactory;
  * string representations.
  *
  * @since Jetty 4.1
- * @version $Revision: 1.12 $
+ * @version $Revision: 1.14 $
  * @author Greg Wilkins (gregw)
  */
 public class TypeUtil
@@ -351,6 +351,12 @@ public class TypeUtil
         return 0;
     }
 
+    /* ------------------------------------------------------------ */
+    public static char toHexChar(int b)
+    {   
+        return (char)(b<10?('0'+b):('A'+b-10));
+    }
+    
     /* ------------------------------------------------------------ */
     public static String toHexString(byte[] b)
     {   
