@@ -1,5 +1,5 @@
 //// ========================================================================
-// $Id: TestRFC2616.java,v 1.29 2004/09/05 08:40:35 gregwilkins Exp $
+// $Id: TestRFC2616.java,v 1.36 2006/04/05 15:24:43 gregwilkins Exp $
 // Copyright 1999-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -42,7 +42,7 @@ import org.mortbay.util.ThreadPool;
 /* ------------------------------------------------------------ */
 /** Test against RFC 2616.
  *
- * @version $Id: TestRFC2616.java,v 1.29 2004/09/05 08:40:35 gregwilkins Exp $
+ * @version $Id: TestRFC2616.java,v 1.36 2006/04/05 15:24:43 gregwilkins Exp $
  * @author Greg Wilkins (gregw)
  */
 public class TestRFC2616
@@ -61,7 +61,7 @@ public class TestRFC2616
     //
     // this inner class creates some files needed for testing of code 
     // involving the ResourceHandler.  instead, it may be cleaner to 
-    // subclass the handler or resource context to fetch data from 
+    // subclass the handler or resource _context to fetch data from 
     // this code instead of going to disk, but that would involve 
     // hacking up the production code to a much larger degree than
     // is necessary to implement certain desired features (Ranges)
@@ -139,13 +139,13 @@ public class TestRFC2616
     
     /* --------------------------------------------------------------- */
     public TestRFC2616()
-        throws Exception
+    throws Exception
     {
-	if (testFiles == null) {
-		docRoot = new File(defaultTestRoot);
-		testFiles = initTestFileData(docRoot);
-	}
-	
+        if (testFiles == null) {
+            docRoot = new File(defaultTestRoot);
+            testFiles = initTestFileData(docRoot);
+        }
+        
         setName("Test");
         setMinThreads(1);
         setMaxThreads(10);
@@ -153,7 +153,7 @@ public class TestRFC2616
         _server=new HttpServer();
         _server.setTrace(true);
         HttpContext context = _server.getContext(null,"/");
-	context.setResourceBase(docRoot.getName());
+        context.setResourceBase(docRoot.getName());
         context.addHandler(new TestTEHandler());
         context.addHandler(new RedirectHandler());
         ResourceHandler rh = new ResourceHandler();
@@ -243,7 +243,13 @@ public class TestRFC2616
     public String getResponses(String request)
         throws IOException
     {
-        return new String(getResponses(request.getBytes()));
+        String responses=new String(getResponses(request.getBytes()));
+        if (log.isDebugEnabled())
+        {
+            System.out.println(request);
+            System.out.println(responses);
+        }
+        return responses;
     }
     
     /* --------------------------------------------------------------- */
@@ -270,7 +276,7 @@ public class TestRFC2616
         test9_2();
         test9_4();
         test9_8();
-  	test10_2_7();	/* 206 Partial Content                         */
+  	    test10_2_7();	/* 206 Partial Content                         */
         test10_3();     /* Redirection 3XX                             */
         test14_16();    /* Content-Range                               */
         test14_23();    /* Host header                                 */
@@ -578,9 +584,9 @@ public class TestRFC2616
         try
         {
             TestRFC2616 listener = new TestRFC2616();
-            listener.getHttpServer().getContext("VirtualHost","/path/*")
-                .addHandler(new DumpHandler());
-            listener.getHttpServer().start();
+            HttpContext context=listener.getHttpServer().getContext("VirtualHost","/path/*");
+            context.addHandler(new DumpHandler());
+            context.start();
             String response;
             int offset=0;
 
@@ -924,49 +930,47 @@ public class TestRFC2616
 
             boolean noRangeHasContentLocation = (response.indexOf("\r\nContent-Location: ") != -1);
 
-
             // now try again for the same resource but this time WITH range header
 
             response=listener.getResponses("GET /" + TestRFC2616.testFiles[0].name + " HTTP/1.1\n"+
                                            "Host: localhost\n"+
                                            "Connection: close\n"+
-                                           "Range: bytes=1-3\n"+
+                                           "Range: bytes=1-3,bytes=6-9\n"+
+                                           "Range: bytes=12-14\n"+
                                            "\n");
 
             if(log.isDebugEnabled())log.debug("RESPONSE: "+response);
             offset=0;
-            offset=t.checkContains(response,offset,
-                                   "HTTP/1.1 206 Partial Content\r\n",
-                                   "1. proper 206 status code");
-            offset=t.checkContains(response,offset, 
-                                   "Content-Type: text/plain",
-                                   "2. content type") + 2;
-            offset=t.checkContains(response,offset,
-                                   "Last-Modified: " + TestRFC2616.testFiles[0].modDate + "\r\n", 
-                                   "3. correct resource mod date");
-
+            offset=t.checkContains(response,offset,"HTTP/1.1 206 Partial Content\r\n","1. proper 206 status code");
+           
             // if GET w/o range had Content-Location, then the corresponding 
             // response for the a GET w/ range must also have that same header
 
+            offset=t.checkContains(response,offset,"--jetty","4a. content type") + 2;
+            offset=t.checkContains(response,offset,"Content-Type: text/plain","4a. content type") + 2;
+            offset=t.checkContains(response,offset,"Content-Range: bytes 1-3/26","4a. content range") + 2;
             offset=t.checkContains(response,offset, 
-                                   "Content-Range: bytes 1-3/26",
-                                   "4. content range") + 2;
-
+                    				TestRFC2616.testFiles[0].data.substring(1, 3+1), 
+                                   "6. subrange data");
+            offset=t.checkContains(response,offset,"--jetty","4b. content type") + 2;
+            offset=t.checkContains(response,offset,"Content-Type: text/plain","4bontent type") + 2;
+            offset=t.checkContains(response,offset,"Content-Range: bytes 6-9/26","4b. content range") + 2;
+            offset=t.checkContains(response,offset, 
+                    				TestRFC2616.testFiles[0].data.substring(6, 9+1), 
+                                   "6. subrange data");
+            offset=t.checkContains(response,offset,"--jetty","4c. content type") + 2;
+            offset=t.checkContains(response,offset,"Content-Type: text/plain","4c. content type") + 2;
+            offset=t.checkContains(response,offset,"Content-Range: bytes 12-14/26","4c. content range") + 2;
+            offset=t.checkContains(response,offset, 
+                    				TestRFC2616.testFiles[0].data.substring(12, 14+1), 
+                                   "6. subrange data");
+             
             if (noRangeHasContentLocation) {
                     offset=t.checkContains(response,offset, 
                                   "Content-Location: ", 
                                   "5. Content-Location header as with 200");
             } 
-            else {
-                    log.debug("no need to check for Conten-Location header in 206 response");
-                    // spec does not require existence or absence if these want any
-                    // header for the get w/o range
-            }
 
-            String expectedData = TestRFC2616.testFiles[0].data.substring(1, 3+1);
-            offset=t.checkContains(response,offset, 
-                                   expectedData, 
-                                   "6. subrange data: \"" + expectedData + "\"");
 	}
         catch(Exception e)
         {
@@ -1408,7 +1412,11 @@ public class TestRFC2616
     
     /* --------------------------------------------------------------- */
     public static void test14_39()
-    {        
+    {      
+        log.debug("NOT HANDLED RFC2616 14.39 TE");
+        return;
+        
+        /*
         TestCase t = new TestCase("RFC2616 14.39 TE");
         try
         {
@@ -1446,6 +1454,7 @@ public class TestRFC2616
             log.warn(LogSupport.EXCEPTION,e);
             t.check(false,e.toString());
         }
+        */
     }
     
     /* --------------------------------------------------------------- */
