@@ -1,5 +1,5 @@
 // ========================================================================
-// $Id: Tests.java,v 1.22 2004/05/09 20:33:34 gregwilkins Exp $
+// $Id: Tests.java,v 1.28 2005/11/03 09:37:56 gregwilkins Exp $
 // Copyright 1997-2004 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -26,7 +26,7 @@ import junit.framework.TestSuite;
 
 /* ------------------------------------------------------------ */
 /** Util meta Tests.
- * @version $Id: Tests.java,v 1.22 2004/05/09 20:33:34 gregwilkins Exp $
+ * @version $Id: Tests.java,v 1.28 2005/11/03 09:37:56 gregwilkins Exp $
  * @author Greg Wilkins (gregw)
  */
 public class Tests extends junit.framework.TestCase
@@ -248,12 +248,13 @@ public class Tests extends junit.framework.TestCase
         assertTrue("c[3].check(c[0])", creds[3].check(creds[0]));
         assertTrue("c[3].check(c[1])", creds[3].check(creds[1]));
         assertTrue("c[3].check(c[2])",!creds[3].check(creds[2]));
-        assertTrue("c[3].check(c[3])",!creds[3].check(creds[3]));
+        assertTrue("c[3].check(c[3])", creds[3].check(creds[3]));
        
     }
 
     /* ------------------------------------------------------------ */
     public void testURI()
+        throws Exception
     {
         URI uri;
 
@@ -472,26 +473,30 @@ public class Tests extends junit.framework.TestCase
         String[][] canonical = 
         {
             {"/aaa/bbb/","/aaa/bbb/"},
-            {"/aaa//bbb/","/aaa/bbb/"},
-            {"/aaa///bbb/","/aaa/bbb/"},
+            {"/aaa//bbb/","/aaa//bbb/"},
+            {"/aaa///bbb/","/aaa///bbb/"},
             {"/aaa/./bbb/","/aaa/bbb/"},
+            {"/aaa//./bbb/","/aaa//bbb/"},
+            {"/aaa/.//bbb/","/aaa//bbb/"},
             {"/aaa/../bbb/","/bbb/"},
             {"/aaa/./../bbb/","/bbb/"},
+            {"/aaa//../bbb/","/aaa/bbb/"},
+            {"/aaa/..//bbb/","//bbb/"},
             {"/aaa/bbb/ccc/../../ddd/","/aaa/ddd/"},
             {"./bbb/","bbb/"},
             {"./aaa/../bbb/","bbb/"},
             {"./",""},
-            {".//",""},
-            {".///",""},
+            {".//",".//"},
+            {".///",".///"},
             {"/.","/"},
-            {"//.","/"},
-            {"///.","/"},
+            {"//.","//"},
+            {"///.","///"},
             {"/","/"},
             {"aaa/bbb","aaa/bbb"},
             {"aaa/","aaa/"},
             {"aaa","aaa"},
             {"/aaa/bbb","/aaa/bbb"},
-            {"/aaa//bbb","/aaa/bbb"},
+            {"/aaa//bbb","/aaa//bbb"},
             {"/aaa/./bbb","/aaa/bbb"},
             {"/aaa/../bbb","/bbb"},
             {"/aaa/./../bbb","/bbb"},
@@ -504,6 +509,7 @@ public class Tests extends junit.framework.TestCase
             {"",""},
             {"..",null},
             {"./..",null},
+            {"//..","/"},
             {"aaa/../..",null},
             {"/foo/bar/../../..",null},
             {"/../foo",null},
@@ -513,15 +519,20 @@ public class Tests extends junit.framework.TestCase
             {"a/.","a/"},
             {"a/..",""},
             {"a/../..",null},
-            {"/foo/../bar//","/bar/"}
+            {"/foo/../bar//","/bar//"},
+            {"/./blah/..","/"},
+            {"//../a/../bb/../ccc/../test///..","/test//"},
         };
 
         for (int t=0;t<canonical.length;t++)
-            assertEquals( "canonical "+canonical[t][0],
-                          URI.canonicalPath(canonical[t][0]),
-                          canonical[t][1]
-                          );
+        {
+            System.err.println(canonical[t][0]+" == "+URI.canonicalPath(canonical[t][0]));
         
+            assertEquals( "canonical "+canonical[t][0],
+                          canonical[t][1],
+                          URI.canonicalPath(canonical[t][0])
+                          );
+        }
     }
 
 
@@ -590,6 +601,11 @@ public class Tests extends junit.framework.TestCase
         assertEquals("encoded encode","Name8=xx%2C++yy++%2Czz", url_encoded.encode());
         assertEquals("encoded get", url_encoded.getString("Name8"),"xx,  yy  ,zz");
 
+        url_encoded.clear();
+        url_encoded.decode("Name9=%83e%83X%83g", "SJIS"); // "Test" in Japanese Katakana
+        assertEquals("encoded param size",1, url_encoded.size());
+        assertEquals("encoded get", "\u30c6\u30b9\u30c8", url_encoded.getString("Name9"));        
+        
         
         byte[] b = new byte[]
             {
