@@ -1,7 +1,13 @@
 package com.acme;
 
-import java.io.*;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStreamWriter;
+import java.io.PrintWriter;
+import java.io.Reader;
 import java.util.Enumeration;
+import java.util.Locale;
+
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletRequestWrapper;
@@ -9,11 +15,30 @@ import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 public class DumpServlet extends HttpServlet
 {
+    
+    /* ------------------------------------------------------------ */
+    /* 
+     * @see javax.servlet.http.HttpServlet#doPost(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
+     */
+    protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException
+    {
+        doGet(req, resp);
+    }
+
     public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException,
             ServletException
     {
+        if (request.getParameter("redirect")!=null)
+        {
+            response.sendRedirect(request.getParameter("redirect"));
+            return;
+        }
+        
         String furi = (String) request.getAttribute("javax.servlet.forward.request_uri");
         if (furi == null) furi = request.getRequestURI();
         String url = request.getScheme() + "://" + request.getServerName() + ":"
@@ -28,6 +53,7 @@ public class DumpServlet extends HttpServlet
         String info = (String) request.getAttribute("javax.servlet.include.path_info");
         if (info == null) info = request.getPathInfo();
 
+        
         PrintWriter out = null;
         try
         {
@@ -40,9 +66,34 @@ public class DumpServlet extends HttpServlet
 
         String referer = request.getHeader("referer");
         response.setContentType("text/html");
+        
 
         out.write("<html><body>");
         out.write("<h1>Dump from " + getServletContext().getServerInfo() + "</h1>");
+
+        /* Some helpful debug
+        out.write("<pre>");
+        out.write("*** Thread.currentThread().getContextClassLoader()="+Thread.currentThread().getContextClassLoader());
+        out.write("\n");
+        out.write("*** this.getClass().getClassLoader()="+this.getClass().getClassLoader());
+        out.write("\n");
+        out.write("*** LogFactory.class.getClassLoader()="+LogFactory.class.getClassLoader());
+        out.write("\n");
+        try
+        {
+            Log log = LogFactory.getLog(DumpServlet.class);
+            out.write("*** log.getclass().getClassLoader() "+log.getClass().getClassLoader());
+            out.write("\n");
+	    log.info("some information");
+        }
+        catch(Throwable th)
+        {
+            th.printStackTrace(out);
+        }
+        out.write("\n");
+        out.write("</pre>");
+	    */
+        
         out.write("<h3>Logical Values</h3>");
         out.write("<table border=\"1\"><tr><th>Name</th><th>Value</th><th>Expected Value</th></tr>");
         out.write("<tr><td>Client URL</td><td>" + url
@@ -94,7 +145,15 @@ public class DumpServlet extends HttpServlet
         }
 
         if (referer != null) out.write("<p><a href=\"" + referer + "\">BACK</a></p>");
-        out.write("</body></html>");
+        
+        out.write("<h3>Content:</h3><pre>");
+        Reader in = request.getReader();
+        int len=0;
+        char[] buf=new char[8096];
+        while ((len=in.read(buf))>=0)
+            out.write(buf, 0, len);
+
+        out.write("</pre></body></html>");
         out.flush();
     }
 }
